**********
What's New
**********

.. toctree::
    :maxdepth: 1

    1.9.rst


Past Releases
-------------
Examples in these documents are frozen in time to respect the status of
the API at the time of the release they are describing. Please refer to
the main, up-to-date documentation if you run into any issues with the
functionality highlighted in these pages.

.. toctree::
    :maxdepth: 1

    1.8.rst
    1.7.rst
    1.6.rst
    1.5.rst
    1.4.rst
    1.3.rst
    1.2.rst
    1.1.rst
